
from math import sin, tanh, sqrt, e, pi 
import numpy as np
import matplotlib.pyplot as plt
import math as math
from scipy import interpolate, ndimage
import matplotlib
matplotlib.use('Agg')

dt = np.dtype('>f8')

nx=100
ny=100
nz=60
dz=0.5
nt=360
depth_max=-30

h = depth_max*np.ones( (nx, ny), dtype=dt)

h[0, :] = 0    # close west boundary
h[-1, :] = 0   # close east boundary
h[:, 0] = 0    # close south boundary
h[:, -1] = 0   # close north boundary

# Write to file in Fortran order
fid = open("bathymetry.bin", "wb")
h.astype(dt).ravel(order='F').tofile(fid)
fid.close()

lw = np.zeros( (nx, ny, nt), dtype=dt)
sw = np.zeros( (nx, ny, nt), dtype=dt)
windy = np.zeros( (nx, ny, nt), dtype=dt)
atemp = np.zeros( (nx, ny, nt), dtype=dt)
RELHUM = np.zeros( (nx, ny, nt), dtype=dt)
for t in range(nt):
 swval=750*sin(2*pi*t/24)
 if swval<0:
  swval=0
 sw[:,:,t]=swval
 lw[:,:,t]=410+30*sin((2*pi*t+3)/24)
 atemp[:,:,t]=273.15+24+sin((2*pi*t+3)/24)
 RELHUM[:,:,t] = 0.65+0.15*sin((2*pi*t+15)/24)
 for i in range(nx):
   windy[i,:,t]=8*sin(2*pi*t/24)*sin(2*pi*i/50)

fid = open("merid_wind.bin", "wb")
windy.ravel(order='F').tofile(fid)
fid.close()


windx = np.zeros( (nx, ny, nt), dtype=dt)
hs = np.zeros( (nx, ny, nt), dtype=dt)
hs[:,:,:]=RELHUM[:,:,:]*100*np.exp(17.67*(atemp[:,:,:]-273.15)/(atemp[:,:,:]-29.65))/(0.263*101650)


fid = open("zonal_wind.bin", "wb")
windx.astype(dt).ravel(order='F').tofile(fid)
fid.close()
fid = open("longwave_rad.bin", "wb")
lw.astype(dt).ravel(order='F').tofile(fid)
fid.close()
fid = open("shortwave_rad.bin", "wb")
sw.astype(dt).ravel(order='F').tofile(fid)
fid.close()
fid = open("HS.bin", "wb")
hs.astype(dt).ravel(order='F').tofile(fid)
fid.close()
fid = open("temperature.bin", "wb")
atemp.astype(dt).ravel(order='F').tofile(fid)
fid.close()

initemp=np.zeros( (nx, ny, nz), dtype=dt)
Tb=10
Ts=25
z0=15
d=1.5


for k in range(nz):
  initemp[:,:,k]=Tb + 0.5 * (Ts - Tb) * (1 + tanh( (z0 - k*dz) / d ) )

fid = open("initial_temp.bin", "wb")
initemp.astype(dt).ravel(order='F').tofile(fid)
fid.close()


